==> ScannerDaemon-0.2.0-src.zip: openantivirus/java/src/org/openantivirus/scanner/TrieScannerTest.java <==
/*
 * $Id: TrieScannerTest.java,v 1.1 2001/12/12 23:59:38 kurti Exp $
 *
 * This file is part of the OpenAntiVirus-Project,
 * see http://www.openantivirus.org/
 * (c) 2001 iKu Netzwerkl&ouml;sungen
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openantivirus.scanner;

import java.util.Iterator;

import junit.framework.*;

/**
 * TrieScannerTest
 *
 * Pattern-Roles:
 * @author  Kurt Huwig
 * @version $Revision: 1.1 $
 */
public class TrieScannerTest extends TestCase {
    public static final String VERSION =
        "$Id: TrieScannerTest.java,v 1.1 2001/12/12 23:59:38 kurti Exp $";
    
    private Trie        trie;
    private TrieScanner trieScanner;
    
    public TrieScannerTest(java.lang.String testName) {
        super(testName);
        
        trie = new Trie();
        trie.addString("ABCdefg", new PositionFoundListener() {
            public void positionFound(PositionFoundEvent pfe)
                    throws VirusFoundException {
                throw new VirusFoundException("Found");
            }
        });
        trie.prepare();
        
        trieScanner = new TrieScanner(trie);
    }        
    
    public void testUpdate() {
        String sTest = "1234567890ABCabcdefghij";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
            fail("Testpattern 1 not found");
        } catch (VirusFoundException vfe) {
            // good!
        }
        
        sTest = "ABCabcdefghij";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
            fail("Testpattern 2 not found");
        } catch (VirusFoundException vfe) {
            // good!
        }
        
        sTest = "1234567890ABC";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
            fail("Testpattern 3 not found");
        } catch (VirusFoundException vfe) {
            // good!
        }
        
        sTest = "1234567890ABxCabcdefghij";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
        } catch (VirusFoundException vfe) {
            fail("Nonexistent pattern found");
        }
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(TrieScannerTest.class);
        
        return suite;
    }
}

==> ScannerDaemon-0.5.1-src.zip: openantivirus/java/src/org/openantivirus/scanner/TrieScannerTest.java <==
/*
 * $Id: TrieScannerTest.java,v 1.2 2002/04/22 09:44:24 kurti Exp $
 *
 * This file is part of the OpenAntiVirus-Project,
 * see http://www.openantivirus.org/
 * (c) 2001 iKu Netzwerkl&ouml;sungen
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openantivirus.scanner;

import java.util.Iterator;

import junit.framework.*;

/**
 * TrieScannerTest
 *
 * Pattern-Roles:
 * @author  Kurt Huwig
 * @version $Revision: 1.2 $
 */
public class TrieScannerTest extends TestCase {
    public static final String VERSION =
        "$Id: TrieScannerTest.java,v 1.2 2002/04/22 09:44:24 kurti Exp $";
    
    private Trie        trie;
    private TrieScanner trieScanner;
    
    public TrieScannerTest(java.lang.String testName) {
        super(testName);
        
        trie = new Trie();
        trie.addString("ABCdefg".getBytes(), new PositionFoundListener() {
            public void positionFound(PositionFoundEvent pfe)
                    throws VirusFoundException {
                throw new VirusFoundException("Found");
            }
        });
        trie.prepare();
        
        trieScanner = new TrieScanner(trie);
    }        
    
    public void testUpdate() {
        String sTest = "1234567890ABCabcdefghij";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
            fail("Testpattern 1 not found");
        } catch (VirusFoundException vfe) {
            // good!
        }
        
        sTest = "ABCabcdefghij";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
            fail("Testpattern 2 not found");
        } catch (VirusFoundException vfe) {
            // good!
        }
        
        sTest = "1234567890ABC";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
            fail("Testpattern 3 not found");
        } catch (VirusFoundException vfe) {
            // good!
        }
        
        sTest = "1234567890ABxCabcdefghij";
        try {
            trieScanner.reset();
            trieScanner.update(sTest.getBytes(), 0, sTest.length(), 0, 0);
        } catch (VirusFoundException vfe) {
            fail("Nonexistent pattern found");
        }
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(TrieScannerTest.class);
        
        return suite;
    }
}
